package com.ruoyi.ehsHiddenDanger.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.ehsHiddenDanger.domain.EhsHiddenDanger;
import java.util.List;

/**
 * 隐患信息Mapper接口
 *
 * @author ruoyi
 * @date 2023-12-11
 */
public interface EhsHiddenDangerMapper extends BaseMapper<EhsHiddenDanger> {
	/**
	 * 查询隐患信息
	 *
	 * @param hiddenDangerId 隐患信息主键
	 * @return 隐患信息
	 */
	public EhsHiddenDanger selectEhsHiddenDangerByHiddenDangerId(Long hiddenDangerId);
	public EhsHiddenDanger selectEhsHiddenDangerOverTime(EhsHiddenDanger ehsHiddenDanger);
	/**
	 * 查询隐患信息列表
	 *
	 * @param ehsHiddenDanger 隐患信息
	 * @return 隐患信息集合
	 */
	public List<EhsHiddenDanger> selectEhsHiddenDangerList(EhsHiddenDanger ehsHiddenDanger);
	public EhsHiddenDanger selectOverTimeId(EhsHiddenDanger ehsHiddenDanger);
	/**
	 * 督办
	 *
	 * @param hiddenDangerIds 部门ID组
	 */
	public int superviseEhsHiddenDanger(Long[] hiddenDangerIds);

	/**
	 * 协办
	 *
	 * @param ehsHiddenDanger 部门ID组
	 */
	public int assistEhsHiddenDanger(EhsHiddenDanger ehsHiddenDanger);
}
